@@ -9,6 +9,7 @@ from uuid import UUID
 import click
 
 from .completion import get_completion_inspect_parameters
+from .core import TyperArgument, TyperCommand
 from .models import (
     AnyType,
     ArgumentInfo,
@@ -47,10 +48,10 @@ class Typer:
         no_args_is_help: Optional[bool] = Default(None),
         subcommand_metavar: Optional[str] = Default(None),
         chain: bool = Default(False),
-        result_callback: Optional[Callable] = Default(None),
+        result_callback: Optional[Callable[..., Any]] = Default(None),
         # Command
         context_settings: Optional[Dict[Any, Any]] = Default(None),
-        callback: Optional[Callable] = Default(None),
+        callback: Optional[Callable[..., Any]] = Default(None),
         help: Optional[str] = Default(None),
         epilog: Optional[str] = Default(None),
         short_help: Optional[str] = Default(None),
@@ -92,7 +93,7 @@ class Typer:
         no_args_is_help: Optional[bool] = Default(None),
         subcommand_metavar: Optional[str] = Default(None),
         chain: bool = Default(False),
-        result_callback: Optional[Callable] = Default(None),
+        result_callback: Optional[Callable[..., Any]] = Default(None),
         # Command
         context_settings: Optional[Dict[Any, Any]] = Default(None),
         help: Optional[str] = Default(None),
@@ -142,7 +143,7 @@ class Typer:
         deprecated: bool = False,
     ) -> Callable[[CommandFunctionType], CommandFunctionType]:
         if cls is None:
-            cls = click.Command
+            cls = TyperCommand
 
         def decorator(f: CommandFunctionType) -> CommandFunctionType:
             self.registered_commands.append(
@@ -175,10 +176,10 @@ class Typer:
         no_args_is_help: Optional[bool] = Default(None),
         subcommand_metavar: Optional[str] = Default(None),
         chain: bool = Default(False),
-        result_callback: Optional[Callable] = Default(None),
+        result_callback: Optional[Callable[..., Any]] = Default(None),
         # Command
         context_settings: Optional[Dict[Any, Any]] = Default(None),
-        callback: Optional[Callable] = Default(None),
+        callback: Optional[Callable[..., Any]] = Default(None),
         help: Optional[str] = Default(None),
         epilog: Optional[str] = Default(None),
         short_help: Optional[str] = Default(None),
@@ -209,8 +210,8 @@ class Typer:
             )
         )
 
-    def __call__(self) -> Any:
-        return get_command(self)()
+    def __call__(self, *args: Any, **kwargs: Any) -> Any:
+        return get_command(self)(*args, **kwargs)
 
 
 def get_group(typer_instance: Typer) -> click.Command:
@@ -420,7 +421,7 @@ def get_command_from_info(command_info: CommandInfo) -> click.Command:
         convertors,
         context_param_name,
     ) = get_params_convertors_ctx_param_name_from_function(command_info.callback)
-    cls = command_info.cls or click.Command
+    cls = command_info.cls or TyperCommand
     command = cls(  # type: ignore
         name=name,
         context_settings=command_info.context_settings,
@@ -449,7 +450,7 @@ def param_path_convertor(value: Optional[str] = None) -> Optional[Path]:
     return None
 
 
-def generate_enum_convertor(enum: Type[Enum]) -> Callable:
+def generate_enum_convertor(enum: Type[Enum]) -> Callable[..., Any]:
     lower_val_map = {str(val.value).lower(): val for val in enum}
 
     def convertor(value: Any) -> Any:
@@ -462,7 +463,7 @@ def generate_enum_convertor(enum: Type[Enum]) -> Callable:
     return convertor
 
 
-def generate_iter_convertor(convertor: Callable[[Any], Any]) -> Callable:
+def generate_iter_convertor(convertor: Callable[[Any], Any]) -> Callable[..., Any]:
     def internal_convertor(value: Any) -> List[Any]:
         return [convertor(v) for v in value]
 
@@ -471,11 +472,11 @@ def generate_iter_convertor(convertor: Callable[[Any], Any]) -> Callable:
 
 def get_callback(
     *,
-    callback: Optional[Callable] = None,
+    callback: Optional[Callable[..., Any]] = None,
     params: Sequence[click.Parameter] = [],
     convertors: Dict[str, Callable[[str], Any]] = {},
-    context_param_name: str = None,
-) -> Optional[Callable]:
+    context_param_name: Optional[str] = None,
+) -> Optional[Callable[..., Any]]:
     if not callback:
         return None
     parameters = get_params_from_function(callback)
@@ -628,7 +629,7 @@ def get_click_param(
         if origin is Union:
             types = []
             for type_ in main_type.__args__:
-                if type_ is NoneType:  # type: ignore
+                if type_ is NoneType:
                     continue
                 types.append(type_)
             assert len(types) == 1, "Typer Currently doesn't support Union types"
@@ -685,7 +686,7 @@ def get_click_param(
             click.Option(
                 # Option
                 param_decls=param_decls,
-                show_default=parameter_info.show_default,
+                show_default=parameter_info.show_default,  # type: ignore
                 prompt=parameter_info.prompt,
                 confirmation_prompt=parameter_info.confirmation_prompt,
                 hide_input=parameter_info.hide_input,
@@ -719,12 +720,18 @@ def get_click_param(
         if is_list:
             nargs = -1
         return (
-            click.Argument(
+            TyperArgument(
                 # Argument
                 param_decls=param_decls,
                 type=parameter_type,
                 required=required,
                 nargs=nargs,
+                # TyperArgument
+                show_default=parameter_info.show_default,
+                show_choices=parameter_info.show_choices,
+                show_envvar=parameter_info.show_envvar,
+                help=parameter_info.help,
+                hidden=parameter_info.hidden,
                 # Parameter
                 default=default_value,
                 callback=get_param_callback(
@@ -742,8 +749,10 @@ def get_click_param(
 
 
 def get_param_callback(
-    *, callback: Optional[Callable] = None, convertor: Optional[Callable] = None
-) -> Optional[Callable]:
+    *,
+    callback: Optional[Callable[..., Any]] = None,
+    convertor: Optional[Callable[..., Any]] = None,
+) -> Optional[Callable[..., Any]]:
     if not callback:
         return None
     parameters = get_params_from_function(callback)
@@ -791,7 +800,9 @@ def get_param_callback(
     return wrapper
 
 
-def get_param_completion(callback: Optional[Callable] = None) -> Optional[Callable]:
+def get_param_completion(
+    callback: Optional[Callable[..., Any]] = None
+) -> Optional[Callable[..., Any]]:
     if not callback:
         return None
     parameters = get_params_from_function(callback)
@@ -842,7 +853,7 @@ def get_param_completion(callback: Optional[Callable] = None) -> Optional[Callab
     return wrapper
 
 
-def run(function: Callable) -> Any:
+def run(function: Callable[..., Any]) -> Any:
     app = Typer()
     app.command()(function)
     app()
